/*
 Copyright (c) 2007, Mike Kinney
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification, are permitted provided that the 
 following conditions are met:
 
 * Redistributions of source code must retain the above copyright notice, this list of conditions and the 
 following disclaimer.
 * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the 
 following disclaimer in the documentation and/or other materials provided with the distribution.
 
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, 
 INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE 
 DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
 SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE 
 USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

//
//  MKFacebook.h
//  MKAbeFook
//
//  Created by Mike on 10/11/06.
//  Copyright 2006 Mike Kinney. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#define MKXMLFacebookDataFormat 0
#define MKJSONFacebookDataFormat 1

@class MKLoginWindow;

extern NSString *MKAPIServerURL;
extern NSString *MKLoginUrl;

@interface MKFacebook : NSObject {
	
	MKLoginWindow *loginWindow;
	NSString *apiKey;
	NSString *secretKey;
	NSString *authToken;
	NSString *sessionKey;
	NSString *sessionSecret;
	NSString *uid;
	BOOL hasAuthToken;
	BOOL hasSessionKey;
	BOOL hasSessionSecret;
	BOOL hasUid;
	BOOL userCancelledLogin;
	NSTimeInterval connectionTimeoutInterval;
	NSError *lastError;
	NSString * facebookAPIVersion;
	id _delegate;
	int facebookDataFormat;
	
}


+(MKFacebook *)facebookWithAPIKey:(NSString *)apiKey withSecret:(NSString *)secretKey delegate:(id)aDelegate;
-(MKFacebook *)initUsingAPIKey:(NSString *)anApi usingSecret:(NSString *)aSecret delegate:(id)aDelegate;

-(NSString *)apiKey;
-(NSString *)sessionKey;
-(NSString *)generateSigWithParameters:(NSDictionary *)parameters;
-(NSString *)generateTimeStamp;

-(NSString *)facebookDataFormat;
-(void)setFacebookDataFormat:(int)aFacebookDataFormat;

-(NSString *)uid;
-(BOOL)userLoggedIn;
-(void)resetFacebookConnection;

//maybe this will be useful in the future
-(void)setFacebookAPIVersion:(NSString *)aFacebookAPIVersion;
-(NSString *)facebookAPIVersion;

//Login Window
-(void)getAuthSession;
-(void)showFacebookLoginWindow;
-(NSWindow *)showFacebookLoginWindowForSheet;
-(void)setConnectionTimeoutInterval:(double)aConnectionTimeoutInterval;
-(NSError *)lastError;
-(id)fetchFacebookData:(NSURL *)theURL;


@end

@interface MKFacebook(MKFacebookDelegateMethods)
-(void)userLoginSuccessful;
-(void)userLoginFailed;
@end

@interface NSString (StringExtras)
- (NSString *) encodeURLLegally;
@end


